@@ -1,4 +1,4 @@
-from client_utils import ClientUtils
+from client_utils.client_utils import ClientUtils
 
 
 class HostClient:
